summaryrefslogtreecommitdiffstats
path: root/kdirstat
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:07:24 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:07:24 -0600
commit3acdcb24dbf879f255e0904b59c06b9cb0b8ef25 (patch)
tree08e25256d7720bd36601047636c3407a57ea861f /kdirstat
parent5cd0f61d88ee0aa08b9a5cbdb84456019d225617 (diff)
downloadkdirstat-3acdcb24dbf879f255e0904b59c06b9cb0b8ef25.tar.gz
kdirstat-3acdcb24dbf879f255e0904b59c06b9cb0b8ef25.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kdirstat')
-rw-r--r--kdirstat/kactivitytracker.cpp8
-rw-r--r--kdirstat/kactivitytracker.h4
-rw-r--r--kdirstat/kcleanup.cpp8
-rw-r--r--kdirstat/kdirstatapp.cpp14
-rw-r--r--kdirstat/kdirstatapp.h6
-rw-r--r--kdirstat/kdirstatsettings.cpp10
-rw-r--r--kdirstat/kdirstatsettings.h2
-rw-r--r--kdirstat/kdirtree.cpp34
-rw-r--r--kdirstat/kdirtree.h16
-rw-r--r--kdirstat/kdirtreeview.cpp8
-rw-r--r--kdirstat/ktreemapview.cpp4
-rw-r--r--kdirstat/ktreemapview.h6
12 files changed, 60 insertions, 60 deletions
diff --git a/kdirstat/kactivitytracker.cpp b/kdirstat/kactivitytracker.cpp
index 5ef31fe..0e98f9e 100644
--- a/kdirstat/kactivitytracker.cpp
+++ b/kdirstat/kactivitytracker.cpp
@@ -22,7 +22,7 @@ KActivityTracker::KActivityTracker( TQObject * parent,
{
_id = id;
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( _id );
_sum = config->readNumEntry( "activityPoints", 0 );
_lastSignal = config->readNumEntry( "lastSignal" , 0 );
@@ -41,7 +41,7 @@ KActivityTracker::setThreshold( long threshold )
{
_threshold = threshold;
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( _id );
config->writeEntry( "threshold", _threshold );
@@ -63,7 +63,7 @@ KActivityTracker::trackActivity( int points )
<< endl;
#endif
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( _id );
config->writeEntry( "activityPoints", _sum );
@@ -79,7 +79,7 @@ KActivityTracker::checkThreshold()
// kdDebug() << "Activity threshold reached for " << _id << endl;
_lastSignal = _sum;
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( _id );
config->writeEntry( "lastSignal", _lastSignal );
diff --git a/kdirstat/kactivitytracker.h b/kdirstat/kactivitytracker.h
index 5c584d6..fb4b83c 100644
--- a/kdirstat/kactivitytracker.h
+++ b/kdirstat/kactivitytracker.h
@@ -35,9 +35,9 @@ class KActivityTracker: public TQObject
public:
/**
- * Constructor. The ID is a name for the KConfig object to look in for
+ * Constructor. The ID is a name for the TDEConfig object to look in for
* accumulated activity points so far. 'initialThreshold' is only used if
- * the application's @ref KConfig object doesn't contain a corresponding
+ * the application's @ref TDEConfig object doesn't contain a corresponding
* entry yet.
**/
KActivityTracker( TQObject * parent,
diff --git a/kdirstat/kcleanup.cpp b/kdirstat/kcleanup.cpp
index 929cc36..3cd6f7e 100644
--- a/kdirstat/kcleanup.cpp
+++ b/kdirstat/kcleanup.cpp
@@ -381,8 +381,8 @@ KCleanup::runCommand ( const KFileInfo * item,
void
KCleanup::readConfig()
{
- KConfig *config = kapp->config();
- KConfigGroupSaver saver( config, _id );
+ TDEConfig *config = kapp->config();
+ TDEConfigGroupSaver saver( config, _id );
bool valid = config->readBoolEntry( "valid", false );
@@ -412,8 +412,8 @@ KCleanup::readConfig()
void
KCleanup::saveConfig() const
{
- KConfig *config = kapp->config();
- KConfigGroupSaver saver( config, _id );
+ TDEConfig *config = kapp->config();
+ TDEConfigGroupSaver saver( config, _id );
config->writeEntry( "valid", true );
config->writeEntry( "command", _command );
diff --git a/kdirstat/kdirstatapp.cpp b/kdirstat/kdirstatapp.cpp
index ce10460..1c07e2e 100644
--- a/kdirstat/kdirstatapp.cpp
+++ b/kdirstat/kdirstatapp.cpp
@@ -345,7 +345,7 @@ KDirStatApp::openURL( const KURL& url )
void KDirStatApp::readMainWinConfig()
{
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "General Options" );
// Status settings of the various bars and views
@@ -385,7 +385,7 @@ void KDirStatApp::readMainWinConfig()
void
KDirStatApp::saveMainWinConfig()
{
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "General Options" );
@@ -403,7 +403,7 @@ KDirStatApp::saveMainWinConfig()
void
-KDirStatApp::saveProperties( KConfig *config )
+KDirStatApp::saveProperties( TDEConfig *config )
{
(void) config;
// TODO
@@ -411,7 +411,7 @@ KDirStatApp::saveProperties( KConfig *config )
void
-KDirStatApp::readProperties( KConfig *config )
+KDirStatApp::readProperties( TDEConfig *config )
{
(void) config;
// TODO
@@ -702,7 +702,7 @@ KDirStatApp::askForFeedback()
if ( ! doFeedbackReminder() )
return;
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
switch ( KMessageBox::warningYesNoCancel( this,
i18n( "Now that you know this program for some time,\n"
@@ -745,7 +745,7 @@ KDirStatApp::askForFeedback()
void
KDirStatApp::feedbackMailSent()
{
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Feedback" );
config->writeEntry( "mailSent", true );
config->sync();
@@ -755,7 +755,7 @@ KDirStatApp::feedbackMailSent()
bool
KDirStatApp::doFeedbackReminder()
{
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Feedback" );
bool mailSent = config->readBoolEntry( "mailSent", false );
diff --git a/kdirstat/kdirstatapp.h b/kdirstat/kdirstatapp.h
index df9e603..d23e5f9 100644
--- a/kdirstat/kdirstatapp.h
+++ b/kdirstat/kdirstatapp.h
@@ -61,7 +61,7 @@ using namespace KDirStat;
*
* @see KMainWindow
* @see TDEApplication
- * @see KConfig
+ * @see TDEConfig
*
* @author Source Framework Automatically Generated by KDevelop,
* (c) The KDevelop Team.
@@ -345,7 +345,7 @@ protected:
*
* @see KTMainWindow#saveProperties
**/
- virtual void saveProperties( KConfig * config );
+ virtual void saveProperties( TDEConfig * config );
/**
* Reads session config file and restore application state including the
@@ -354,7 +354,7 @@ protected:
*
* @see KTMainWindow#readProperties
**/
- virtual void readProperties( KConfig * config );
+ virtual void readProperties( TDEConfig * config );
/**
diff --git a/kdirstat/kdirstatsettings.cpp b/kdirstat/kdirstatsettings.cpp
index 0183727..c30c6b6 100644
--- a/kdirstat/kdirstatsettings.cpp
+++ b/kdirstat/kdirstatsettings.cpp
@@ -740,7 +740,7 @@ KGeneralSettingsPage::~KGeneralSettingsPage()
void
KGeneralSettingsPage::apply()
{
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Directory Reading" );
config->writeEntry( "CrossFileSystems", _crossFileSystems->isChecked() );
@@ -769,7 +769,7 @@ KGeneralSettingsPage::revertToDefaults()
void
KGeneralSettingsPage::setup()
{
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Directory Reading" );
_crossFileSystems->setChecked ( config->readBoolEntry( "CrossFileSystems" , false) );
@@ -932,7 +932,7 @@ KTreemapPage::~KTreemapPage()
void
KTreemapPage::apply()
{
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Treemaps" );
@@ -982,7 +982,7 @@ KTreemapPage::revertToDefaults()
void
KTreemapPage::setup()
{
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Treemaps" );
_squarify->setChecked ( config->readBoolEntry( "Squarify" , true ) );
@@ -1024,7 +1024,7 @@ KTreemapPage::checkEnabledState()
TQColor
-KTreemapPage::readColorEntry( KConfig * config, const char * entryName, TQColor defaultColor )
+KTreemapPage::readColorEntry( TDEConfig * config, const char * entryName, TQColor defaultColor )
{
return config->readColorEntry( entryName, &defaultColor );
}
diff --git a/kdirstat/kdirstatsettings.h b/kdirstat/kdirstatsettings.h
index dd2dde8..2985f56 100644
--- a/kdirstat/kdirstatsettings.h
+++ b/kdirstat/kdirstatsettings.h
@@ -699,7 +699,7 @@ namespace KDirStat
/**
* Convenience method to read a color from 'config'.
**/
- TQColor readColorEntry( KConfig * config,
+ TQColor readColorEntry( TDEConfig * config,
const char * entryName,
TQColor defaultColor );
diff --git a/kdirstat/kdirtree.cpp b/kdirstat/kdirtree.cpp
index e80e916..47c609d 100644
--- a/kdirstat/kdirtree.cpp
+++ b/kdirstat/kdirtree.cpp
@@ -140,7 +140,7 @@ KFileInfo::KFileInfo( const KFileItem * fileItem,
_isSparseFile = false;
}
- _mtime = fileItem->time( KIO::UDS_MODIFICATION_TIME );
+ _mtime = fileItem->time( TDEIO::UDS_MODIFICATION_TIME );
}
@@ -1010,23 +1010,23 @@ KAnyDirReadJob::startReading()
kdWarning() << k_funcinfo << "URL malformed: " << _dir->url() << endl;
}
- _job = KIO::listDir( url,
+ _job = TDEIO::listDir( url,
false ); // showProgressInfo
- connect( _job, TQT_SIGNAL( entries( KIO::Job *, const KIO::UDSEntryList& ) ),
- this, TQT_SLOT ( entries( KIO::Job *, const KIO::UDSEntryList& ) ) );
+ connect( _job, TQT_SIGNAL( entries( TDEIO::Job *, const TDEIO::UDSEntryList& ) ),
+ this, TQT_SLOT ( entries( TDEIO::Job *, const TDEIO::UDSEntryList& ) ) );
- connect( _job, TQT_SIGNAL( result ( KIO::Job * ) ),
- this, TQT_SLOT ( finished( KIO::Job * ) ) );
+ connect( _job, TQT_SIGNAL( result ( TDEIO::Job * ) ),
+ this, TQT_SLOT ( finished( TDEIO::Job * ) ) );
- connect( _job, TQT_SIGNAL( canceled( KIO::Job * ) ),
- this, TQT_SLOT ( finished( KIO::Job * ) ) );
+ connect( _job, TQT_SIGNAL( canceled( TDEIO::Job * ) ),
+ this, TQT_SLOT ( finished( TDEIO::Job * ) ) );
}
void
-KAnyDirReadJob::entries ( KIO::Job * job,
- const KIO::UDSEntryList & entryList )
+KAnyDirReadJob::entries ( TDEIO::Job * job,
+ const TDEIO::UDSEntryList & entryList )
{
NOT_USED( job );
KURL url( _dir->url() ); // Cache this - it's expensive!
@@ -1036,7 +1036,7 @@ KAnyDirReadJob::entries ( KIO::Job * job,
kdWarning() << k_funcinfo << "URL malformed: " << _dir->url() << endl;
}
- KIO::UDSEntryListConstIterator it = entryList.begin();
+ TDEIO::UDSEntryListConstIterator it = entryList.begin();
while ( it != entryList.end() )
{
@@ -1076,7 +1076,7 @@ KAnyDirReadJob::entries ( KIO::Job * job,
void
-KAnyDirReadJob::finished( KIO::Job * job )
+KAnyDirReadJob::finished( TDEIO::Job * job )
{
if ( job->error() )
_dir->setReadState( KDirError );
@@ -1099,9 +1099,9 @@ KAnyDirReadJob::stat( const KURL & url,
KDirTree * tree,
KDirInfo * parent )
{
- KIO::UDSEntry uds_entry;
+ TDEIO::UDSEntry uds_entry;
- if ( KIO::NetAccess::stat( url, uds_entry, tqApp->mainWidget() ) ) // remote stat() OK?
+ if ( TDEIO::NetAccess::stat( url, uds_entry, tqApp->mainWidget() ) ) // remote stat() OK?
{
KFileItem entry( uds_entry, url,
true, // determine MIME type on demand
@@ -1128,9 +1128,9 @@ KAnyDirReadJob::stat( const KURL & url,
TQString
KAnyDirReadJob::owner( KURL url )
{
- KIO::UDSEntry uds_entry;
+ TDEIO::UDSEntry uds_entry;
- if ( KIO::NetAccess::stat( url, uds_entry, tqApp->mainWidget() ) ) // remote stat() OK?
+ if ( TDEIO::NetAccess::stat( url, uds_entry, tqApp->mainWidget() ) ) // remote stat() OK?
{
KFileItem entry( uds_entry, url,
true, // determine MIME type on demand
@@ -1181,7 +1181,7 @@ KDirTree::~KDirTree()
void
KDirTree::readConfig()
{
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Directory Reading" );
_crossFileSystems = config->readBoolEntry( "CrossFileSystems", false );
diff --git a/kdirstat/kdirtreeview.cpp b/kdirstat/kdirtreeview.cpp
index f0cea2e..a2f75cd 100644
--- a/kdirstat/kdirtreeview.cpp
+++ b/kdirstat/kdirtreeview.cpp
@@ -852,8 +852,8 @@ KDirTreeView::popupContextInfo( const TQPoint & pos,
void
KDirTreeView::readConfig()
{
- KConfig *config = kapp->config();
- KConfigGroupSaver saver( config, "Tree Colors" );
+ TDEConfig *config = kapp->config();
+ TDEConfigGroupSaver saver( config, "Tree Colors" );
_usedFillColors = config->readNumEntry( "usedFillColors", -1 );
if ( _usedFillColors < 0 )
@@ -887,8 +887,8 @@ KDirTreeView::readConfig()
void
KDirTreeView::saveConfig() const
{
- KConfig *config = kapp->config();
- KConfigGroupSaver saver( config, "Tree Colors" );
+ TDEConfig *config = kapp->config();
+ TDEConfigGroupSaver saver( config, "Tree Colors" );
config->writeEntry( "usedFillColors", _usedFillColors );
diff --git a/kdirstat/ktreemapview.cpp b/kdirstat/ktreemapview.cpp
index 43f07b6..6509738 100644
--- a/kdirstat/ktreemapview.cpp
+++ b/kdirstat/ktreemapview.cpp
@@ -115,7 +115,7 @@ KTreemapView::deleteAllItems( TQCanvas * canvas )
void
KTreemapView::readConfig()
{
- KConfig * config = kapp->config();
+ TDEConfig * config = kapp->config();
config->setGroup( "Treemaps" );
_ambientLight = config->readNumEntry( "AmbientLight" , DefaultAmbientLight );
@@ -148,7 +148,7 @@ KTreemapView::readConfig()
TQColor
-KTreemapView::readColorEntry( KConfig * config, const char * entryName, TQColor defaultColor )
+KTreemapView::readColorEntry( TDEConfig * config, const char * entryName, TQColor defaultColor )
{
return config->readColorEntry( entryName, &defaultColor );
}
diff --git a/kdirstat/kdirtree.h b/kdirstat/kdirtree.h
index 6746fd8..abadd7e 100644
--- a/kdirstat/kdirtree.h
+++ b/kdirstat/kdirtree.h
@@ -81,7 +81,7 @@ namespace KDirStat
*
* Information about one single directory entry. This is the type of info
* typically obtained by stat() / lstat() or similar calls. Most of this
* can also be obtained by @ref KIO::KDirListJob, but not all: The device
* this file resides on is something none of KIO's many classes will tell
* (since of course this only makes sense for local files) - yet this had
* been _the_ single most requested feature of KDirStat <1.0: Stay on one
@@ -118,7 +118,7 @@ namespace KDirStat
KDirInfo * parent = 0 );
/**
* Constructor from a KFileItem, i.e. from a @ref KIO::StatJob
**/
KFileInfo( const KFileItem * fileItem,
KDirTree * tree,
@@ -610,7 +610,7 @@ namespace KDirStat
KDirInfo * parent = 0 );
/**
* Constructor from a KFileItem, i.e. from a @ref KIO::StatJob
**/
KDirInfo( const KFileItem * fileItem,
KDirTree * tree,
@@ -1073,17 +1073,17 @@ namespace KDirStat
/**
* Receive directory entries from a KIO job.
**/
- void entries( KIO::Job * job,
- const KIO::UDSEntryList & entryList );
+ void entries( TDEIO::Job * job,
+ const TDEIO::UDSEntryList & entryList );
/**
* KIO job is finished.
**/
- void finished( KIO::Job * job );
+ void finished( TDEIO::Job * job );
protected:
- KIO::ListJob * _job;
+ TDEIO::ListJob * _job;
};
@@ -1366,7 +1366,7 @@ namespace KDirStat
void timeSlicedRead();
/**
- * Read some parameters from the global @ref KConfig object.
+ * Read some parameters from the global @ref TDEConfig object.
**/
void readConfig();
@@ -81,7 +81,7 @@ namespace KDirStat
* Information about one single directory entry. This is the type of info
* typically obtained by stat() / lstat() or similar calls. Most of this
- * can also be obtained by @ref KIO::KDirListJob, but not all: The device
+ * can also be obtained by @ref TDEIO::KDirListJob, but not all: The device
* this file resides on is something none of KIO's many classes will tell
* (since of course this only makes sense for local files) - yet this had
@@ -118,7 +118,7 @@ namespace KDirStat
KDirInfo * parent = 0 );
/**
- * Constructor from a KFileItem, i.e. from a @ref KIO::StatJob
+ * Constructor from a KFileItem, i.e. from a @ref TDEIO::StatJob
**/
KFileInfo( const KFileItem * fileItem,
@@ -610,7 +610,7 @@ namespace KDirStat
KDirInfo * parent = 0 );
/**
- * Constructor from a KFileItem, i.e. from a @ref KIO::StatJob
+ * Constructor from a KFileItem, i.e. from a @ref TDEIO::StatJob
**/
KDirInfo( const KFileItem * fileItem,
diff --git a/kdirstat/ktreemapview.h b/kdirstat/ktreemapview.h
index 61e4de6..63d8b8b 100644
--- a/kdirstat/ktreemapview.h
+++ b/kdirstat/ktreemapview.h
@@ -32,7 +32,7 @@
class TQMouseEvent;
-class KConfig;
+class TDEConfig;
namespace KDirStat
{
@@ -168,7 +168,7 @@ namespace KDirStat
void deleteNotify( KFileInfo * node );
/**
* Read some parameters from the global @ref KConfig object.
**/
void readConfig();
@@ -373,7 +373,7 @@ namespace KDirStat
/**
* Convenience method to read a color from 'config'.
**/
- TQColor readColorEntry( KConfig * config,
+ TQColor readColorEntry( TDEConfig * config,
const char * entryName,
TQColor defaultColor );
@@ -168,7 +168,7 @@ namespace KDirStat
void deleteNotify( KFileInfo * node );
/**
- * Read some parameters from the global @ref KConfig object.
+ * Read some parameters from the global @ref TDEConfig object.
**/
void readConfig();